import 'dart:io';

import 'package:meta_audio_lite/android/android_metadata_parser.dart';
import 'package:meta_audio_lite/apple/apple_mac_metadata_parser.dart';
import 'package:meta_audio_lite/apple/apple_metadata_parser.dart';
import 'package:meta_audio_lite/metadata.dart';
import 'package:meta_audio_lite/metadata_parser.dart';

class MetaAudio extends MetadataParser {
  List<MetadataParser> parsers = [];

  MetaAudio() {
    parsers = MetaAudio.defaultParsers;
  }

  setPatterns(List<MetadataParser> pr) {
    parsers = pr;
  }

  static List<MetadataParser> get defaultParsers {
    return [
      if (Platform.isIOS) AppleMetadataParser(),
      if (Platform.isMacOS) AppleMacMetadataParser(),
      if (Platform.isAndroid) AndroidMetadataParser(),
    ];
  }


  @override
  Future<Metadata?> parse(String path, [Map<String, dynamic>? options]) async {
    assert(parsers != null);
    for (var parser in parsers) {
      final metadata = await parser.parse(path, options);
      if (metadata != null) {
        return metadata;
      }
    }

    return null;
  }
}
